( function () {
    /**
     * header object.
     * 
     * It contains all the functionality related to the header.
     * 
     * @since 2.0.0
     * @type object
     */
    var header = {
        /**
         * Sets, binds, and runs functions.
         * 
         * @since 2.0.0
         */
        init: function () {
            this.searchFormOpener = document.querySelector( '#gf-navbar-search-form-opener' );
            this.searchFormCloser = document.querySelectorAll( '.gf-search-form-closer' );
            this.searchForm = document.querySelector( '#gf-navbar-search-form' );
            this.mainMenu = document.querySelector( '#gf-main-menu' );
            this.events = this.events.bind( this );
            this.positionNavbar = this.positionNavbar.bind( this );
            this.setBodyPaddingTop = this.setBodyPaddingTop.bind( this );
            this.openSearchForm = this.openSearchForm.bind( this );
            this.closeSearchForm = this.closeSearchForm.bind( this );

            this.events();
        },

        /**
         * Listens for events.
         * 
         * @since 2.0.0
         * @since 2.0.1 Added the click event listener for two new elements.
         * @listens event:DOMContentLoaded
         * @listens event:resize
         * @listens event:scroll
         * @listens event:click
         */
        events: function () {
            document.addEventListener( 'DOMContentLoaded', this.setBodyPaddingTop );
            window.addEventListener( 'resize', this.setBodyPaddingTop );
            window.addEventListener( 'scroll', this.positionNavbar );

            if ( this.searchFormOpener ) {
                this.searchFormOpener.addEventListener( 'click', this.openSearchForm );
            }

            if ( this.searchFormCloser ) {
                this.searchFormCloser.forEach( function ( elem ) {
                    elem.addEventListener( 'click', this.closeSearchForm );
                }.bind( this ) );
            }
        },

        /**
         * Positions the navbar on mobile devices when the adminbar exists.
         * 
         * @since 2.0.0
         */
        positionNavbar: function () {
            var navbar = document.querySelector( '#gf-navbar' );

            if ( document.body.classList.contains( 'logged-in' ) && window.matchMedia( "(max-width: 600px)" ).matches ) {
                if ( window.pageYOffset >= 1 ) {
                    navbar.classList.add( 'gf-navbar--no-top' );
                } else {
                    navbar.classList.remove( 'gf-navbar--no-top' );
                }
            }
        },

        /**
         * Set the body element padding top.
         * 
         * @since 2.0.0
         */
        setBodyPaddingTop: function () {
            var navbar = document.querySelector( '#gf-navbar' );
            var navbarHeight = navbar.offsetHeight;

            document.body.style.paddingTop = ( 20 + navbarHeight ) + 'px';
        },

        /**
         * Displays the search form, hides the search form opener button and main menu.
         * 
         * @param object e
         * @since 2.0.1
         * @since 2.0.2 Checks if main menu exists before hiding it.
         */
        openSearchForm: function ( e ) {
            e.preventDefault();

            if ( this.mainMenu ) {
                this.mainMenu.classList.add( 'gf-main-menu--hidden' );
            }

            this.searchFormOpener.classList.add( 'gf-navbar-search-form-opener--hidden' );
            this.searchForm.classList.add( 'gf-navbar-search-form--open' );
        },

        /**
         * Hides the search form, displays the search form opener button and main menu.
         *
         * @param object e
         * @since 2.0.1
         * @since 2.0.2 Checks if main menu exists before displaying it.
         */
        closeSearchForm( e ) {
            e.preventDefault();

            this.searchForm.classList.remove( 'gf-navbar-search-form--open' );

            setTimeout( function () {
                if ( this.mainMenu ) {
                    this.mainMenu.classList.remove( 'gf-main-menu--hidden' );
                }

                this.searchFormOpener.classList.remove( 'gf-navbar-search-form-opener--hidden' );
            }.bind( this ), 200 );
        }
    };

    header.init();
} )();
