<?php
/**
 * GF_Bootstrap_Walker_Nav_Menu class
 * 
 * @since 2.0.0
 */

if ( ! class_exists( 'GF_Bootstrap_Walker_Nav_Menu' ) ) {
    /**
     * Class used to traverse menus so they can look like Bootstrap navbar menus.
     * 
     * @since 2.0.0
     */
    class GF_Bootstrap_Walker_Nav_Menu extends Walker_Nav_Menu {
        /**
         * Starts the list before the elements are added.
         *
         * @since 2.0.0
         *
         * @see Walker::start_lvl()
         *
         * @param string   $output Used to append additional content (passed by reference).
         * @param int      $depth  Depth of menu item. Used for padding.
         * @param stdClass $args   An object of wp_nav_menu() arguments.
         */
        function start_lvl( &$output, $depth = 0, $args = array() ) {
            if ( isset( $args->item_spacing ) && 'discard' === $args->item_spacing ) {
                $t = '';
                $n = '';
            } else {
                $t = "\t";
                $n = "\n";
            }
            $indent = str_repeat( $t, $depth );

            // Default class.
            $classes = array( 'sub-menu', 'dropdown-menu' );

            /**
             * Filters the CSS class(es) applied to a menu list element.
             *
             * @since 2.0.0
             *
             * @param string[] $classes Array of the CSS classes that are applied to the menu `<ul>` element.
             * @param stdClass $args    An object of `wp_nav_menu()` arguments.
             * @param int      $depth   Depth of menu item. Used for padding.
             */
            $class_names = implode( ' ', apply_filters( 'nav_menu_submenu_css_class', $classes, $args, $depth ) );
            $class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

            $output .= "{$n}{$indent}<ul$class_names>{$n}";
        }

        /**
         * Ends the list of after the elements are added.
         *
         * @since 2.0.0
         *
         * @see Walker::end_lvl()
         *
         * @param string   $output Used to append additional content (passed by reference).
         * @param int      $depth  Depth of menu item. Used for padding.
         * @param stdClass $args   An object of wp_nav_menu() arguments.
         */
        function end_lvl( &$output, $depth = 0, $args = array() ) {
            if ( isset( $args->item_spacing ) && 'discard' === $args->item_spacing ) {
                $t = '';
                $n = '';
            } else {
                $t = "\t";
                $n = "\n";
            }
            $indent  = str_repeat( $t, $depth );
            $output .= "$indent</ul>{$n}";
        }

        /**
         * Starts the element output.
         *
         * @since 2.0.0
         *
         * @see Walker::start_el()
         *
         * @param string   $output Used to append additional content (passed by reference).
         * @param WP_Post  $item   Menu item data object.
         * @param int      $depth  Depth of menu item. Used for padding.
         * @param stdClass $args   An object of wp_nav_menu() arguments.
         * @param int      $id     Current item ID.
         */
        function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
            if ( isset( $args->item_spacing ) && 'discard' === $args->item_spacing ) {
                $t = '';
                $n = '';
            } else {
                $t = "\t";
                $n = "\n";
            }

            $indent     = ( $depth ) ? str_repeat( $t, $depth ) : '';
            $classes    = ( empty( $item->classes ) ) ? array() : (array) $item->classes;
            $classes[]  = ( 0 === $depth ) ? 'nav-item' : 0;
            $classes[]  = ( 0 === $depth && in_array( 'menu-item-has-children', $classes ) ) ? 'dropdown' : '';
            $classes[]  = ( $item->current ) ? 'active' : '';

            /**
             * Filters the arguments for a single nav menu item.
             *
             * @since 2.0.0
             *
             * @param stdClass $args  An object of wp_nav_menu() arguments.
             * @param WP_Post  $item  Menu item data object.
             * @param int      $depth Depth of menu item. Used for padding.
             */
            $args = apply_filters( 'nav_menu_item_args', $args, $item, $depth );

            /**
             * Filters the CSS classes applied to a menu item's list item element.
             *
             * @since 2.0.0
             *
             * @param string[] $classes Array of the CSS classes that are applied to the menu item's `<li>` element.
             * @param WP_Post  $item    The current menu item.
             * @param stdClass $args    An object of wp_nav_menu() arguments.
             * @param int      $depth   Depth of menu item. Used for padding.
             */
            $class_names = implode( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args, $depth ) );
            $class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

            /**
             * Filters the ID applied to a menu item's list item element.
             *
             * @since 2.0.0
             *
             * @param string   $menu_id The ID that is applied to the menu item's `<li>` element.
             * @param WP_Post  $item    The current menu item.
             * @param stdClass $args    An object of wp_nav_menu() arguments.
             * @param int      $depth   Depth of menu item. Used for padding.
             */
            $id = apply_filters( 'nav_menu_item_id', 'menu-item-' . $item->ID, $item, $args, $depth );
            $id = $id ? ' id="' . esc_attr( $id ) . '"' : '';

            $output .= ( $depth ) ? '' : $indent . '<li' . $id . $class_names . '>';

            $atts                   = array();
            $atts['title']          = ! empty( $item->attr_title ) ? $item->attr_title : '';
            $atts['target']         = ! empty( $item->target ) ? $item->target : '';
            $atts['rel']            = ! empty( $item->xfn ) ? $item->xfn : '';
            $atts['href']           = ! empty( $item->url ) ? $item->url : '';
            $atts['aria-current']   = $item->current ? 'page' : '';
            $atts['id']             = ( 0 === $depth && in_array( 'menu-item-has-children', $classes ) ) ? 'gf-navbar-dropdown-' . $item->ID : '';
            $atts['role']           = ( 0 === $depth && in_array( 'menu-item-has-children', $classes ) ) ? 'button': '';
            $atts['data-toggle']    = ( 0 === $depth && in_array( 'menu-item-has-children', $classes ) ) ? 'dropdown' : '';
            $atts['aria-haspopup']  = ( 0 === $depth && in_array( 'menu-item-has-children', $classes ) ) ? 'true' : '';
            $atts['aria-expanded']  = ( 0 === $depth && in_array( 'menu-item-has-children', $classes ) ) ? 'false' : '';      

            /**
             * Filters the HTML attributes applied to a menu item's anchor element.
             *
             * @since 2.0.0
             *
             * @param array $atts {
             *     The HTML attributes applied to the menu item's `<a>` element, empty strings are ignored.
             *
             *     @type string $title        Title attribute.
             *     @type string $target       Target attribute.
             *     @type string $rel          The rel attribute.
             *     @type string $href         The href attribute.
             *     @type string $aria_current The aria-current attribute.
             * }
             * @param WP_Post  $item  The current menu item.
             * @param stdClass $args  An object of wp_nav_menu() arguments.
             * @param int      $depth Depth of menu item. Used for padding.
             */
            $atts = apply_filters( 'nav_menu_link_attributes', $atts, $item, $args, $depth );

            $attributes = '';

            foreach ( $atts as $attr => $value ) {
                if ( ! empty( $value ) ) {
                    $value       = ( 'href' === $attr ) ? esc_url( $value ) : esc_attr( $value );
                    $attributes .= ' ' . $attr . '="' . $value . '"';
                }
            }

            /** This filter is documented in wp-includes/post-template.php */
            $title = apply_filters( 'the_title', $item->title, $item->ID );

            /** This filter is documented in wp-includes/post-template.php */
		    $title = apply_filters( 'the_title', $item->title, $item->ID );

            /**
             * Filters a menu item's title.
             *
             * @since 2.0.0
             *
             * @param string   $title The menu item's title.
             * @param WP_Post  $item  The current menu item.
             * @param stdClass $args  An object of wp_nav_menu() arguments.
             * @param int      $depth Depth of menu item. Used for padding.
             */
            $title = apply_filters( 'nav_menu_item_title', $title, $item, $depth );

            if ( 0 === $depth && in_array( 'menu-item-has-children', $classes ) ) {
                $item_class_names = 'nav-link dropdown-toggle';
            } else if ( 0 === $depth && ! in_array( 'menu-item-has-children', $classes ) ) {
                $item_class_names = 'nav-link';
            } else if ( $depth && $item->current ) {
                $item_class_names = 'dropdown-item active';
            } else  {
                $item_class_names = 'dropdown-item';
            }

            $item_output  = $args->before;
            $item_output .= '<a class="' . esc_attr( $item_class_names ) . '" ' . $attributes . '>';
            $item_output .= $args->link_before . $title . $args->link_after;
            $item_output .= '</a>';
            $item_output .= $args->after;

            /**
             * Filters a menu item's starting output.
             *
             * The menu item's starting output only includes `$args->before`, the opening `<a>`,
             * the menu item's title, the closing `</a>`, and `$args->after`. Currently, there is
             * no filter for modifying the opening and closing `<li>` for a menu item.
             *
             * @since 2.0.0
             *
             * @param string   $item_output The menu item's starting HTML output.
             * @param WP_Post  $item        Menu item data object.
             * @param int      $depth       Depth of menu item. Used for padding.
             * @param stdClass $args        An object of wp_nav_menu() arguments.
             */
            $output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
        }

        /**
         * Ends the element output, if needed.
         *
         * @since 2.0.0
         *
         * @see Walker::end_el()
         *
         * @param string   $output Used to append additional content (passed by reference).
         * @param WP_Post  $item   Page data object. Not used.
         * @param int      $depth  Depth of page. Not Used.
         * @param stdClass $args   An object of wp_nav_menu() arguments.
         */
        function end_el( &$output, $object, $depth = 0, $args = array() ) {
            if ( isset( $args->item_spacing ) && 'discard' === $args->item_spacing ) {
                $t = '';
                $n = '';
            } else {
                $t = "\t";
                $n = "\n";
            }
            $output .= ( $depth ) ? "{$n}" : "</li>{$n}";
        }
    }
}
