<?php

if ( ! function_exists( 'go_first_customize_register' ) ) {
	/**
	 * Registers Customizers settings for the theme.
	 * 
	 * This does include:
	 * - Blog section.
	 *   - Show featured section.
	 *   - Show top stories section.
	 *   - Hide sidebar setting.
	 * - Footer section.
	 *   - Copyright text.
	 *   - Social network links.
	 *
	 * @since 1.0.0
	 * @since 2.0.0 Added the navbar_expand setting and navbar_expand_input control in the Blog section.
	 *              Added the primary and secondary theme colors controls in the Colors section.
	 * 				Added control to select a Featured story from the sticky posts.
	 */
	function go_first_customize_register( $wp_customize ) {
		$wp_customize->add_setting( 'primary_color', array(
			'default' 			=> '#4285f4',
			'transport' 		=> 'refresh',
			'type' 				=> 'theme_mod',
			'capability' 		=> 'edit_theme_options',
			'sanitize_callback' => 'go_first_sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'primary_color_input', array(
			'label' 		=> __( 'Primary Theme Color', 'go-first' ),
			'description' 	=> __( 'Primary color: for links, buttons, and active states.', 'go-first' ),
			'section' 		=> 'colors',
			'priority' 		=> 30,
			'settings' 		=> 'primary_color',
		) ) );

		$wp_customize->add_setting( 'secondary_color', array(
			'default' 			=> '#347cf3',
			'transport' 		=> 'refresh',
			'type' 				=> 'theme_mod',
			'capability' 		=> 'edit_theme_options',
			'sanitize_callback' => 'go_first_sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'secondary_color_input', array(
			'label' 		=> __( 'Secondary Theme Color', 'go-first' ),
			'description' 	=> __( 'Secondary color: for links and buttons hover states.', 'go-first' ),
			'section' 		=> 'colors',
			'priority' 		=> 40,
			'settings' 		=> 'secondary_color',
		) ) );

		// Blog
		$wp_customize->add_section( 'blog', array(
			'priority'        => 150,
			'capability'      => 'edit_theme_options',
			'title'           => __( 'Blog', 'go-first' ),
		) );

		$wp_customize->add_setting( 'show_featured', array(
			'default'    		=> false,
			'transport'  		=> 'refresh',
			'type'       		=> 'theme_mod',
			'capability' 		=> 'edit_theme_options',
			'sanitize_callback' => 'go_first_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'show_featured_input', array(
			'priority' => 10,
			'section'  => 'blog',
			'type'     => 'checkbox',
			'settings' => 'show_featured',
			'label'    => __( 'Show Featured Story', 'go-first' ),
		) );

		$wp_customize->add_setting( 'featured_story_id', array(
			'default' 			=> '',
			'transport' 		=> 'refresh',
			'type' 				=> 'theme_mod',
			'capability' 		=> 'edit_theme_options',
			'sanitize_callback' => 'sanitize_key',
		) );

		$sticky_post_choices 	= array( '' => __( '--Select--', 'go-first' ) );
		$sticky_posts_ids 		= get_option( 'sticky_posts' );

		if ( ! empty( $sticky_posts_ids ) ) {
			$sticky_posts = get_posts( array(
				'post__in' 			=> $sticky_posts_ids,
				'post_status' 		=> 'publish',
				'posts_per_page' 	=> -1,
				'order' 			=> 'ASC',
				'orderby' 			=> 'title',
			) );

			if ( ! empty( $sticky_posts ) ) {
				foreach ( $sticky_posts as $key => $post ) {
					$sticky_post_choices[ $post->ID ] = $post->post_title;
				}
			}
		}

		$wp_customize->add_control( 'featured_story_id_input', array(
			'priority' 		=> 10,
			'section'  		=> 'blog',
			'type'     		=> 'select',
			'settings' 		=> 'featured_story_id',
			'label'    		=> __( 'Featured Story', 'go-first' ),
			'description' 	=> __( 'Select one of the following sticky posts to be displayed as Featured Story (posts must have been made sticky previously).', 'go-first' ),
			'choices'		=> $sticky_post_choices,
		) );

		$wp_customize->add_setting( 'show_top_stories', array(
			'default'    		=> false,
			'transport'  		=> 'refresh',
			'type'       		=> 'theme_mod',
			'sanitize_callback' => 'go_first_sanitize_checkbox',
			'capability' 		=> 'edit_theme_options',
		) );

		$wp_customize->add_control( 'show_top_stories_input', array(
			'priority' 		=> 20,
			'section'  		=> 'blog',
			'type'     		=> 'checkbox',
			'settings' 		=> 'show_top_stories',
			'label'    		=> __( 'Show Top Stories', 'go-first' ),
			'description' 	=> __( 'This option will display up to the 3 most recent sticky posts as Top Stories.', 'go-first' )
		) );

		$wp_customize->add_setting( 'hide_sidebar', array(
			'default'    		=> false,
			'transport'  		=> 'refresh',
			'type'       		=> 'theme_mod',
			'capability' 		=> 'edit_theme_options',
			'sanitize_callback' => 'go_first_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'hide_sidebar_input', array(
			'priority' => 30,
			'section'  => 'blog',
			'type'     => 'checkbox',
			'settings' => 'hide_sidebar',
			'label'    => __( 'Hide Sidebar (only applies to the posts page)', 'go-first' ),
		) );

		$wp_customize->add_setting( 'navbar_expand', array(
			'default' 			=> 'lg',
			'transport' 		=> 'refresh',
			'type' 				=> 'theme_mod',
			'capability' 		=> 'edit_theme_options',
			'sanitize_callback' => 'sanitize_key',
		) );

		$wp_customize->add_control( 'navbar_expand_input', array(
			'priority' 		=> 40,
			'section' 		=> 'blog',
			'type' 			=> 'radio',
			'settings' 		=> 'navbar_expand',
			'label' 		=> __( 'Navbar Expand Breakpoint', 'go-first' ),
			'description' 	=> __( 'Breakpoint in which the links are displayed horizontally in the main menu.', 'go-first' ),
			'choices' 		=> array(
				'sm' => __( 'Small (at 576px)', 'go-first' ),
				'md' => __( 'Medium (at 768px)', 'go-first' ),
				'lg' => __( 'Large (at 992px)', 'go-first' ),
				'xl' => __( 'Extra Large (at 1200px)', 'go-first' ),
			),
		) );

		// Footer
		$wp_customize->add_section( 'footer', array(
			'priority'   => 160,
			'capability' => 'edit_theme_options',
			'title'      => __( 'Footer', 'go-first' ),
		) );

		$wp_customize->add_setting( 'copyright_text', array(
			'default' 			=> '',
			'transport' 		=> 'refresh',
			'type' 				=> 'theme_mod',
			'capability' 		=> 'edit_theme_options',
			'sanitize_callback' => 'sanitize_text_field',
		) );

		$wp_customize->add_control( 'copyright_text_input', array(
			'priority' => 10,
			'type'     => 'text',
			'section'  => 'footer',
			'settings' => 'copyright_text',
			'label'    => __( 'Copyright text', 'go-first' ),
		) );

		// Social Networks Links
		$social_networks = array(
			array( 'id' => 'facebook_link',    'name' => esc_html__( 'Facebook', 'go-first' ), ),
			array( 'id' => 'twitter_link',     'name' => esc_html__( 'Twitter', 'go-first' ), ),
			array( 'id' => 'instagram_link',   'name' => esc_html__( 'Instagram', 'go-first' ), ),
			array( 'id' => 'linked_in_link',   'name' => esc_html__( 'LinkedIn', 'go-first' ), ),
			array( 'id' => 'youtube_link',     'name' => esc_html__( 'YouTube', 'go-first' ), ),
			array( 'id' => 'pinterest_link',   'name' => esc_html__( 'Pinterest', 'go-first' ), ),
		);
		$initial_priority = 20;

		foreach ( $social_networks as $social_network ) {
			$wp_customize->add_setting( $social_network['id'], array(
				'default'    		=> '',
				'transport'  		=> 'refresh',
				'type'       		=> 'theme_mod',
				'sanitize_callback' => 'esc_url_raw',
				'capability' 		=> 'edit_theme_options',
			) );

			$wp_customize->add_control( $social_network['id'] . '_input', array(
				'type'        => 'text',
				'section'     => 'footer',
				'priority'    => $initial_priority,
				'settings'    => $social_network['id'],
				/* translators: %s: Social network name */
				'label'       => sprintf( __( '%s link', 'go-first' ), $social_network['name'] ),
				/* translators: %s: Social network name */
				'description' => sprintf( __( 'If not empty a %s icon will appear linking to the provided url', 'go-first' ), $social_network['name'] ),
			) );

			$initial_priority += 10;
		}
		// End Footer

	}

	// customize_register action hook.
	add_action( 'customize_register', 'go_first_customize_register' );
}
